@@ -302,9 +302,10 @@ OPARI2_Directive::ExitRegion( bool end_outer )
         d_top->FinishRegion();
     }
 
+    int region_id = d_top->GetID();
     DirectiveStackPop();
 
-    return d_top->GetID();
+    return region_id;
 }
 
 
