@@ -233,7 +233,7 @@ OPARI2_FortranParser::is_sub_unit_header( void )
                   ( continuation && m_in_header ) );
 
     /* Debug output */
-    /*std::cout << lline << std::endl;
+    /*std::cout << std::endl << lline << std::endl;
        std::cout << "continuation= " << continuation << std::endl;
        std::cout << "m_in_header= " << m_in_header << std::endl;
        std::cout << "func= " << func << std::endl;
@@ -244,7 +244,8 @@ OPARI2_FortranParser::is_sub_unit_header( void )
        std::cout << "openbrackets= " << openbrackets << std::endl;
        std::cout << "inModule= " << inModule << std::endl;
        std::cout << "inInterface= " << inInterface << std::endl;
-       std::cout << "inContains= " << inContains << std::endl;*/
+       std::cout << "inContains= " << inContains << std::endl;
+       std::cout << "noend= " << noend << std::endl;*/
 
     if ( ( ( sline.find( "program" ) == 0 || func || sub || key ) &&
            noend && validequal )     ||
